@@ -22,12 +22,19 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
-package App::Muter::Main;
-$App::Muter::Main::VERSION = '0.001001';
+package App::Muter;
+$App::Muter::VERSION = '0.002000';
 require 5.010001;
 
 use strict;
 use warnings;
+
+
+## no critic(ProhibitMultiplePackages)
+package App::Muter::Main;
+$App::Muter::Main::VERSION = '0.002000';
+use strict;
+use warnings;
 use experimental 'switch';
 
 use App::Muter::Backend ();
@@ -39,18 +46,19 @@ use IO::File            ();
 
 use File::stat;
 
-
 sub script {
     my (@args) = @_;
 
     my $chain = '';
     my $help;
     my $verbose;
+    my $reverse;
     Getopt::Long::GetOptionsFromArray(
         \@args,
-        'chain|c=s' => \$chain,
-        'verbose|v' => \$verbose,
-        'help'      => \$help
+        'chain|c=s'  => \$chain,
+        'verbose|v'  => \$verbose,
+        'reverse|r!' => \$reverse,
+        'help'       => \$help
         ) or
         return usage(1);
 
@@ -59,7 +67,7 @@ sub script {
     return usage(0, $verbose) if $help;
     return usage(1) unless $chain;
 
-    run_chain($chain, load_handles(\@args), \*STDOUT);
+    run_chain($chain, $reverse, load_handles(\@args), \*STDOUT);
 
     return 0;
 }
@@ -82,9 +90,9 @@ sub load_handles {
 }
 
 sub run_chain {
-    my ($chain, $handles, $stdout, $blocksize) = @_;
+    my ($chain, $reverse, $handles, $stdout, $blocksize) = @_;
 
-    $chain = App::Muter::Chain->new($chain);
+    $chain = App::Muter::Chain->new($chain, $reverse);
     $blocksize ||= 512;
 
     foreach my $io (@$handles) {
@@ -101,7 +109,7 @@ sub usage {
     my ($ret, $verbose) = @_;
     my $fh = $ret ? \*STDERR : \*STDOUT;
     $fh->print(<<'EOM');
-muter -c CHAIN | --chain CHAIN [FILES...]
+muter [-r | --reverse] -c CHAIN | --chain CHAIN [FILES...]
 muter [--verbose] --help
 
 Modify the bytes in the concatentation of FILES (or standard input) by using the
@@ -115,6 +123,8 @@ parentheses, a single comma may be used.
 For example, '-hex:hash(sha256):base64' (or '-hex:hash,sha256:base64') decodes a
 hex-encoded string, hashes it with SHA-256, and converts the result to base64.
 
+If --reverse is specified, reverse the order of transforms in order and in sense.
+
 The following transforms are available:
 EOM
     my $reg = App::Muter::Registry->instance;
@@ -136,9 +146,8 @@ EOM
     return $ret;
 }
 
-## no critic(ProhibitMultiplePackages)
 package App::Muter::Interface;
-$App::Muter::Interface::VERSION = '0.001001';
+$App::Muter::Interface::VERSION = '0.002000';
 sub process {
     my ($chain, $data) = @_;
 
@@ -150,7 +159,7 @@ sub process {
 }
 
 package App::Muter::Registry;
-$App::Muter::Registry::VERSION = '0.001001';
+$App::Muter::Registry::VERSION = '0.002000';
 use File::Spec;
 
 my $instance;
@@ -194,7 +203,7 @@ sub load_backends {
 }
 
 package App::Muter::Backend::Chunked;
-$App::Muter::Backend::Chunked::VERSION = '0.001001';
+$App::Muter::Backend::Chunked::VERSION = '0.002000';
 our @ISA = qw/App::Muter::Backend/;
 
 sub new {
@@ -242,7 +251,7 @@ sub _with_chunk {
 }
 
 package App::Muter::Backend::ChunkedDecode;
-$App::Muter::Backend::ChunkedDecode::VERSION = '0.001001';
+$App::Muter::Backend::ChunkedDecode::VERSION = '0.002000';
 our @ISA = qw/App::Muter::Backend/;
 
 sub new {
@@ -282,7 +291,7 @@ sub decode_final {
 }
 
 package App::Muter::Backend::Base64;
-$App::Muter::Backend::Base64::VERSION = '0.001001';
+$App::Muter::Backend::Base64::VERSION = '0.002000';
 use MIME::Base64 ();
 
 our @ISA = qw/App::Muter::Backend::Chunked/;
@@ -332,7 +341,7 @@ sub decode_chunk {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::URL64;
-$App::Muter::Backend::URL64::VERSION = '0.001001';
+$App::Muter::Backend::URL64::VERSION = '0.002000';
 use MIME::Base64 3.11 ();
 our @ISA = qw/App::Muter::Backend::Base64/;
 
@@ -354,7 +363,7 @@ sub decode_chunk {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Hex;
-$App::Muter::Backend::Hex::VERSION = '0.001001';
+$App::Muter::Backend::Hex::VERSION = '0.002000';
 our @ISA = qw/App::Muter::Backend::Chunked/;
 
 sub new {
@@ -395,7 +404,7 @@ sub decode_chunk {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Base16;
-$App::Muter::Backend::Base16::VERSION = '0.001001';
+$App::Muter::Backend::Base16::VERSION = '0.002000';
 our @ISA = qw/App::Muter::Backend::Hex/;
 
 sub new {
@@ -414,7 +423,7 @@ sub metadata {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Base32;
-$App::Muter::Backend::Base32::VERSION = '0.001001';
+$App::Muter::Backend::Base32::VERSION = '0.002000';
 our @ISA = qw/App::Muter::Backend::Chunked/;
 
 sub new {
@@ -508,7 +517,7 @@ sub metadata {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Base32Hex;
-$App::Muter::Backend::Base32Hex::VERSION = '0.001001';
+$App::Muter::Backend::Base32Hex::VERSION = '0.002000';
 our @ISA = qw/App::Muter::Backend::Base32/;
 
 sub new {
@@ -525,7 +534,7 @@ sub new {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::URI;
-$App::Muter::Backend::URI::VERSION = '0.001001';
+$App::Muter::Backend::URI::VERSION = '0.002000';
 our @ISA = qw/App::Muter::Backend::ChunkedDecode/;
 
 sub new {
@@ -568,7 +577,7 @@ sub decode_chunk {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::XML;
-$App::Muter::Backend::XML::VERSION = '0.001001';
+$App::Muter::Backend::XML::VERSION = '0.002000';
 our @ISA = qw/App::Muter::Backend::ChunkedDecode/;
 
 sub new {
@@ -626,7 +635,7 @@ sub decode_chunk {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::QuotedPrintable;
-$App::Muter::Backend::QuotedPrintable::VERSION = '0.001001';
+$App::Muter::Backend::QuotedPrintable::VERSION = '0.002000';
 our @ISA = qw/App::Muter::Backend::ChunkedDecode/;
 
 sub new {
@@ -703,7 +712,7 @@ sub metadata {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Vis;
-$App::Muter::Backend::Vis::VERSION = '0.001001';
+$App::Muter::Backend::Vis::VERSION = '0.002000';
 our @ISA = qw/App::Muter::Backend::ChunkedDecode/;
 
 sub new {
@@ -840,7 +849,7 @@ sub metadata {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Ascii85;
-$App::Muter::Backend::Ascii85::VERSION = '0.001001';
+$App::Muter::Backend::Ascii85::VERSION = '0.002000';
 our @ISA = qw/App::Muter::Backend::Chunked/;
 
 sub new {
@@ -937,7 +946,7 @@ sub decode_final {
 App::Muter::Registry->instance->register(__PACKAGE__);
 
 package App::Muter::Backend::Hash;
-$App::Muter::Backend::Hash::VERSION = '0.001001';
+$App::Muter::Backend::Hash::VERSION = '0.002000';
 use Digest::MD5;
 use Digest::SHA;
 
@@ -998,11 +1007,11 @@ __END__
 
 =head1 NAME
 
-App::Muter::Main - tool to convert between various formats and encodings
+App::Muter - tool to convert between various formats and encodings
 
 =head1 VERSION
 
-version 0.001001
+version 0.002000
 
 =head1 DESCRIPTION
 
