@@ -1,6 +1,6 @@
 package App::Muter::Chain;
 # ABSTRACT: main programmatic interface to muter
-$App::Muter::Chain::VERSION = '0.001001';
+$App::Muter::Chain::VERSION = '0.002000';
 use strict;
 use warnings;
 
@@ -8,10 +8,11 @@ use List::Util ();
 
 
 sub new {
-    my ($class, $chain) = @_;
+    my ($class, $chain, $reverse) = @_;
     $class = ref($class) || $class;
     my $self = bless {}, $class;
-    $self->{chain} = [$self->_instantiate($self->_parse_chain($chain))];
+    $self->{chain} =
+        [$self->_instantiate($self->_parse_chain($chain, $reverse))];
     return $self;
 }
 
@@ -30,18 +31,18 @@ sub final {
 }
 
 sub _chain_entry {
-    my ($item) = @_;
+    my ($item, $reverse) = @_;
     if ($item =~ /^(-?)(\w+)(?:\(([^)]+)\))?$/) {
         return {
             name   => $2,
-            method => ($1 ? 'decode' : 'encode'),
+            method => (($1 xor $reverse) ? 'decode' : 'encode'),
             args   => ($3 ? [split /,/, $3] : []),
         };
     }
     elsif ($item =~ /^(-?)(\w+),([^)]+)$/) {
         return {
             name   => $2,
-            method => ($1 ? 'decode' : 'encode'),
+            method => (($1 xor $reverse) ? 'decode' : 'encode'),
             args   => ($3 ? [split /,/, $3] : []),
         };
     }
@@ -51,9 +52,10 @@ sub _chain_entry {
 }
 
 sub _parse_chain {
-    my (undef, $chain) = @_;
+    my (undef, $chain, $reverse) = @_;
     my @items = split /:/, $chain;
-    return map { _chain_entry($_) } @items;
+    my @chain = map { _chain_entry($_, $reverse) } @items;
+    return $reverse ? reverse @chain : @chain;
 }
 
 sub _instantiate {
@@ -79,7 +81,7 @@ App::Muter::Chain - main programmatic interface to muter
 
 =head1 VERSION
 
-version 0.001001
+version 0.002000
 
 =head1 SYNOPSIS
 
@@ -97,10 +99,11 @@ chain and processes data incrementally, in whatever size chunks it's given.
 
 =head1 METHODS
 
-=head2 $class->new($chain)
+=head2 $class->new($chain, [$reverse])
 
 Create a new chain object using the specified chain, which is identical to the
-argument to muter's B<-c> option.
+argument to muter's B<-c> option.  If C<$reverse> is passed, reverse the chain,
+as with muter's <-r> option.
 
 =head2 $self->process($data)
 
